------------------------------------------------------------------------------[[
-- Filename: test_main.lua
--
-- Description: This file serves as a directory for all available functional tests
-- that are used by the TestMode class. All test categories and the properties of
-- those categories are listed in this file. Categories reserve a range of test IDs
-- so that every test ID is a unique integer. Each category is required to have the
-- following information defined.
--
-- name: A short name for the category of tests
-- description: A longer piece of text describing what the tests in this category perform
-- min_id: The low end of the range of test IDs reserved by the category
-- max_id: The high end of the range of test IDs reserved by the category
-- file: The filename where the tests for this category are defined
--
-- If any of this information is missing, the test category will not appear in TestMode.
-- Although note that it is acceptable for a test file to contain no tests and the category
-- for the test will still appear in this case.
------------------------------------------------------------------------------]]

local ns = {}
setmetatable(ns, {__index = _G})
test_main = ns;
setfenv(1, ns);

-- A table which holds the names of each test category table in this file
categories = {}

--------------------------------------------------------------------------------
-- Mode code tests: Reserve test IDs 1 - 10,000
--------------------------------------------------------------------------------

----- maps: Reserve test IDs 1 - 1,000
table.insert(categories, "maps");
maps = {
	name = "Test Map Mode";
	description = "Used for testing specific features of MapMode and playtesting maps that are under developed. " ..
		"These tests begin by initializing some set of global data (character, inventory, past events completed, etc.), " ..
		"specifying the map file to be used, and then configuring additional properties prior to starting the map. " ..
		"For example, placing the player sprite at a specific position on the map, or marking any number of events that " .. 
		"take place on the map as completed.";
	min_id = 1;
	max_id = 1000;
	file = "lua/test/maps.lua";
}

----- battles: Reserve test IDs 1,001 - 2,000
table.insert(categories, "battles");
battles = {
	name = "Test Battle Mode";
	description = "Used to test battles and perform balance testing. These tests specify the character and enemy parties " ..
		"that will partcipate in the battle. The test may also add custom properties to an actor, such as granting them " ..
		"access to a particular skill that they may otherwise not have. Note that battles can be chained together so that " ..
		"one test involves participating in multiple battles one right after the other. The battles may contain scripted  " ..
		"sequences as well.";
	min_id = 1001;
	max_id = 2000;
	file = "lua/test/battles.lua";
}

----- menus: Reserve test IDs 2,001 - 3,000
table.insert(categories, "menus");
menus = {
	name = "Test Menu Mode";
	description = "Opens up a MenuMode instance. The differences between these sets of tests are all based on the character " ..
		"party, inventory, and other global data. These tests are primarily used for debugging various features of MenuMode " ..
		"and are not used for any sort of game balance testing.";
	min_id = 2001;
	max_id = 3000;
	file = "lua/test/menus.lua";
}

----- shops: Reserve test IDs 3,001 - 4,000
table.insert(categories, "shops");
shops = {
	name = "Test Shop Mode";
	description = "Opens up a shop with custom wares and buy/sell prices. The number of drunes and inventory held by the party are " ..
		"commonly adjusted to ensure that the wares for sale can be afforded or not. These tests are commonly used to adjust " ..
		"the prices of items and equipment sold in the game so that they are a fair price. Tests are also manufactured to debug " ..
		"certain features of ShopMode itself.";
	min_id = 3001;
	max_id = 4000;
	file = "lua/test/shops.lua";
}

----- saves: Reserve test IDs 4,001 - 5,000
table.insert(categories, "saves");
saves = {
	name = "Test Save Mode";
	description = "Tests the Save/Load game interface. These tests only cover either saving or loading of a game, but not both within " ..
		"the same test. Loading a game also requires that saved game files currently exist, as these tests will not write custom saved " ..
		"game files. It is common to rely on existing saves that the user generated by playing through the game,";
	min_id = 4001;
	max_id = 5000;
	file = "lua/test/saves.lua";
}

--------------------------------------------------------------------------------
-- Common code tests: Reserve test IDs 10,001 - 20,000
--------------------------------------------------------------------------------



--------------------------------------------------------------------------------
-- Engine code tests: Reserve test IDs 20,001 - 30,000
--------------------------------------------------------------------------------



--------------------------------------------------------------------------------
-- Utility code tests: Reserve test IDs 30,001 - 40,000
--------------------------------------------------------------------------------



